@@ -18,8 +18,12 @@ module RR
       recorded_calls.clear
     end
 
-    def add(subject, method_name, arguments, block)
-      recorded_calls << RecordedCall.new(subject, method_name, arguments, block)
+    def add(subject, method_name, arguments, keyword_arguments, block)
+      recorded_calls << RecordedCall.new(subject,
+                                         method_name,
+                                         arguments,
+                                         keyword_arguments,
+                                         block)
     end
 
     def any?(&block)
@@ -81,22 +85,28 @@ module RR
 
     def match_double_injection(spy_verification)
       lambda do |recorded_call|
-        recorded_call[0] == spy_verification.subject &&
-        recorded_call[1] == spy_verification.method_name
+        recorded_call.subject == spy_verification.subject &&
+          recorded_call.method_name == spy_verification.method_name
       end
     end
 
     def match_argument_expectation(spy_verification)
       lambda do |recorded_call|
-        spy_verification.argument_expectation.exact_match?(*recorded_call[2]) ||
-        spy_verification.argument_expectation.wildcard_match?(*recorded_call[2])
+        expectation = spy_verification.argument_expectation
+        arguments = recorded_call.arguments
+        keyword_arguments = recorded_call.keyword_arguments
+        expectation.exact_match?(arguments, keyword_arguments) ||
+          expectation.wildcard_match?(arguments, keyword_arguments)
       end
     end
 
     def invocation_count_error(spy_verification, matching_recorded_calls)
+      method_name = spy_verification.method_name
+      arguments = spy_verification.argument_expectation.expected_arguments
+      keyword_arguments = spy_verification.argument_expectation.expected_keyword_arguments
       RR::Errors.build_error(RR::Errors::SpyVerificationErrors::InvocationCountError,
         "On subject #{spy_verification.subject.inspect}\n" <<
-        "Expected #{Double.formatted_name(spy_verification.method_name, spy_verification.argument_expectation.expected_arguments)}\n" <<
+        "Expected #{Double.formatted_name(method_name, arguments, keyword_arguments)}\n" <<
         "to be called #{spy_verification.times_matcher.expected_times_message},\n" <<
         "but was called #{matching_recorded_calls.size} times.\n" <<
         "All of the method calls related to Doubles are:\n" <<
