@@ -16,8 +16,8 @@ module RR
       end
 
       def attempt?(times_called)
-        raise RR::Errors::TimesCalledError, error_message(1)
+        raise RR::Errors.build_error(:TimesCalledError, error_message(1))
       end
     end
   end
-end
\ No newline at end of file
+end
