@@ -8,11 +8,11 @@ module RR
       def ==(other)
         other.is_a?(self.class)
       end
-      alias_method :eql?, :==
+      alias :eql? :==
 
       def inspect
         'anything'
       end
     end
   end
-end
\ No newline at end of file
+end
