@@ -6,6 +6,8 @@ require 'rr/core_ext/array'
 require 'rr/core_ext/range'
 require 'rr/core_ext/regexp'
 
+require 'rr/keyword_arguments'
+
 require 'rr/class_instance_method_defined'
 require 'rr/blank_slate'
 
@@ -51,7 +53,6 @@ require 'rr/method_dispatches/method_missing_dispatch'
 require 'rr/hash_with_object_id_key'
 require 'rr/recorded_call'
 require 'rr/recorded_calls'
-require 'rr/proc_from_block'
 
 require 'rr/double_definitions/double_definition_create_blank_slate'
 require 'rr/double_definitions/double_definition_create'
